@@ -30,9 +30,6 @@ date             init     comment
 20-jan-07    abb      Begun.
 */
 
-#include <libxml/xmlstring.h>
-#include <libxml/xmlreader.h>
-
 #ifndef _H_dlq
 #include  "dlq.h"
 #endif
