@@ -31,8 +31,7 @@ date	     init     comment
 12-nov-05    abb      Begun
 
 */
-
-#include <libxml/xmlstring.h>
+#include <stdio.h>
 
 #ifndef _H_dlq
 #include "dlq.h"
