@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2008 - 2012, Andy Bierman, All Rights Reserved.
+ * Copyright (c) 2013 - 2018, Vladimir Vassilev, All Rights Reserved.
  * 
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -8,7 +9,7 @@
  * specific language governing permissions and limitations
  * under the License.    
  */
-/*  FILE: mgr_val_parse.c
+/*  FILE: val_parse.c
 
                 
 *********************************************************************
@@ -34,8 +35,8 @@ date         init     comment
 #include <string.h>
 #include <math.h>
 
-#include <xmlstring.h>
-#include <xmlreader.h>
+#include <libxml/xmlstring.h>
+#include <libxml/xmlreader.h>
 
 
 #include "procdefs.h"
@@ -1223,19 +1224,14 @@ static status_t
  *
  * <foo>fred</foo>
  * <foo>11</foo>
+ * <foo/>
+ * <foo></foo>
  *
  * INPUTS:
- *     scb == session control block
- *            Input is read from scb->reader.
- *     obj == object template for this string type
- *     startnode == top node of the parameter to be parsed
- *            Parser function will attempt to consume all the
- *            nodes until the matching endnode is reached
- *     retval ==  val_value_t that should get the results of the parsing
+ *   see parse_btype parameter list
  *     
  * OUTPUTS:
  *    *retval will be filled in
- *    msg->errQ may be appended with new errors or warnings
  *
  * RETURNS:
  *   status
@@ -1250,6 +1246,8 @@ static status_t
     xml_node_t           valnode, endnode;
     status_t             res, res2;
     boolean              stopnow;
+    boolean              empty;
+
 
     /* init local vars */
     xml_init_node(&valnode);
@@ -1257,20 +1255,55 @@ static status_t
     res2 = NO_ERR;
     errinfo = NULL;
     stopnow = FALSE;
+    empty = FALSE;
 
     val_init_from_template(retval, obj);
 
     /* make sure the startnode is correct */
     res = xml_node_match(startnode, 
-                         obj_get_nsid(obj), 
+                         obj_get_nsid(obj),
                          NULL, 
                          XML_NT_START); 
-    if (res == NO_ERR) {
-        /* get the next node which should be a string node */
-        res = get_xml_node(scb, &valnode);
+    if (res != NO_ERR) {
+        res = xml_node_match(startnode,
+                             obj_get_nsid(obj),
+                             NULL,
+                             XML_NT_EMPTY);
+        if (res == NO_ERR) {
+            empty = TRUE;
+        }
     }
 
-    if (res == NO_ERR) {
+    /* get the value string node */
+    if (res == NO_ERR && !empty) {
+        /* get the next node which should be a string node */
+        res = get_xml_node(scb, &valnode);
+        if (res == NO_ERR && valnode.nodetyp == XML_NT_END) {
+
+            res = xml_endnode_match(startnode, &valnode);
+            if(res==NO_ERR) {
+                empty = TRUE;
+                xml_clean_node(&valnode);
+            }
+        }
+    }
+
+
+    if (empty && res==NO_ERR) {
+        /* check the empty string */
+        res = val_union_ok_errinfo(obj_get_typdef(obj),
+                                   EMPTY_STRING,
+                                   retval,
+                                   &errinfo);
+        if(res==NO_ERR) {
+            retval->v.str = xml_strdup(EMPTY_STRING);
+            if (!retval->v.str) {
+                res = ERR_INTERNAL_MEM;
+            }
+        }
+    }
+
+    if(res == NO_ERR && !empty) {
 #ifdef MGR_VAL_PARSE_DEBUG
         if (LOGDEBUG4) {
             log_debug4("\nparse_union: expecting string or number node.");
@@ -1280,10 +1313,6 @@ static status_t
 
         /* validate the node type and union node content */
         switch (valnode.nodetyp) {
-        case XML_NT_START:
-            res = ERR_NCX_WRONG_NODETYP_CPX;
-            stopnow = TRUE;
-            break;
         case XML_NT_STRING:
             /* get the non-whitespace string here */
             res = val_union_ok_errinfo(obj_get_typdef(obj), 
@@ -1291,13 +1320,6 @@ static status_t
                                        retval, 
                                        &errinfo);
             break;
-        case XML_NT_END:
-            stopnow = TRUE;
-            res = val_union_ok_errinfo(obj_get_typdef(obj), 
-                                       EMPTY_STRING, 
-                                       retval, 
-                                       &errinfo);
-            break;
         default:
             stopnow = TRUE;
             SET_ERROR(ERR_INTERNAL_VAL);
@@ -1915,13 +1937,21 @@ static status_t
     status_t     res, res2, res3;
     boolean      nserr;
 
+    if (LOGDEBUG3) {
+        log_debug3("%s: %s:%s btyp:%s",
+                   __FUNCTION__,
+                   obj_get_mod_prefix(obj),
+                   obj_get_name(obj),
+                   tk_get_btype_sym(obj_get_basetype(obj)));
+    }
+
     btyp = obj_get_basetype(obj);
 
     /* get the attribute values from the start node */
     retval->nsid = startnode->nsid;
 
-    /* check namespace errors except if the type is ANY */
-    nserr = (btyp != NCX_BT_ANY);
+    /* check namespace errors except if the type is ANY* */
+    nserr = (btyp != NCX_BT_ANYDATA && btyp != NCX_BT_ANYXML);
 
     /* parse the attributes, if any; do not quick exit on this error */
     res2 = parse_metadata(obj, startnode, nserr, retval);
@@ -1930,7 +1960,8 @@ static status_t
      * to record as many errors as possible
      */
     switch (btyp) {
-    case NCX_BT_ANY:
+    case NCX_BT_ANYDATA:
+    case NCX_BT_ANYXML:
         res = parse_any(scb, startnode, retval);
         break;
     case NCX_BT_ENUM:
@@ -2013,15 +2044,31 @@ static status_t
     }
 
     if (res != NO_ERR) {
-        retval->res = res;
-        return res;
+        res3 = res;
     } else if (res2 != NO_ERR) {
-        retval->res = res2;
-        return res2;
+        res3 = res2;
     }
 
-    retval->res = res3;
-    return res3;
+    /* Reporting errors only once */
+    if(res3!=NO_ERR) {
+        if(retval->res == NO_ERR) {
+            if (LOGDEBUG3) {
+                SET_ERROR(res3);
+            }
+            retval->res = res3;
+        } else {
+            if (LOGDEBUG3) {
+                log_debug3("%s: %s:%s btyp:%s overwriting retval->res=%s with res=%s",
+                   __FUNCTION__,
+                   obj_get_mod_prefix(obj),
+                   obj_get_name(obj),
+                   tk_get_btype_sym(obj_get_basetype(obj)),
+                   get_error_string(retval->res),
+                   get_error_string(res3));
+            }
+        }
+    }
+    return retval->res;
 
 } /* parse_btype */
 
@@ -2064,8 +2111,8 @@ static status_t
     /* get the attribute values from the start node */
     retval->nsid = startnode->nsid;
 
-    /* check namespace errors except if the type is ANY */
-    nserr = (btyp != NCX_BT_ANY);
+    /* check namespace errors except if the type is ANY* */
+    nserr = (btyp != NCX_BT_ANYDATA && btyp != NCX_BT_ANYXML);
 
     /* parse the attributes, if any; do not quick exit on this error */
     res2 = parse_metadata(obj, startnode, nserr, retval);
@@ -2074,7 +2121,8 @@ static status_t
      * to record as many errors as possible
      */
     switch (btyp) {
-    case NCX_BT_ANY:
+    case NCX_BT_ANYDATA:
+    case NCX_BT_ANYXML:
         res = parse_any(scb, startnode, retval);
         break;
     case NCX_BT_ENUM:
