@@ -31,7 +31,7 @@ date         init     comment
 #include  <string.h>
 #include  <memory.h>
 
-#include <xmlstring.h>
+#include <libxml/xmlstring.h>
 
 #ifndef _H_procdefs
 #include  "procdefs.h"
