@@ -1,4 +1,5 @@
 /* Structure describing a word-expansion run.*/
+#define YANGCLI_WORDEXP_MAXPARAMS_NUM 1024
 typedef struct {
     size_t we_wordc;            /* Count of words matched.  */
     char **we_wordv;            /* List of expanded words.  */
@@ -7,3 +8,4 @@ typedef struct {
 
 int yangcli_wordexp (const char* words, yangcli_wordexp_t* pwordexp, int flags);
 void yangcli_wordfree (yangcli_wordexp_t * pwordexp);
+void yangcli_wordexp_dump(yangcli_wordexp_t * pwordexp);
