@@ -23,7 +23,9 @@
 #include <ctype.h>
 #include <time.h>
 #include <sys/time.h>
-#include <assert.h>
+#ifdef DEBUG
+# include <assert.h>
+#endif
 
 #include "mgr.h"
 
@@ -82,215 +84,9 @@ static void
                                   mgr_not_msg_t *msg,
                                   boolean *consumed)
 {
-    assert(0);
+    log_debug2("\n%s called", __func__);
 }
 
-/********************************************************************
- * FUNCTION do_connect_
- * 
- * INPUTS:
- *   server_cb == server control block to use
- *   rpc == rpc header for 'connect' command
- *   line == input text from readline call, not modified or freed here
- *   start == byte offset from 'line' where the parse RPC method
- *            left off.  This is eiother empty or contains some 
- *            parameters from the user
- *   startupmode == TRUE if starting from init and should try
- *              to connect right away if the mandatory parameters
- *              are present.
- *               == FALSE to check --optional and add parameters
- *                  if set or any missing mandatory parms
- *
- * OUTPUTS:
- *   connect_valset parms may be set 
- *   create_session may be called
- *
- * RETURNS:
- *   status
- *********************************************************************/
-status_t
-    do_connect_ (server_cb_t *server_cb,
-                obj_template_t *rpc,
-                const xmlChar *line,
-                uint32 start,
-                boolean startupmode)
-{
-    obj_template_t        *obj;
-    val_value_t           *connect_valset;
-    val_value_t           *valset, *testval;
-    status_t               res;
-    boolean                s1, s2, s3, s4, s5, tcp;
-
-#ifdef DEBUG
-    if (server_cb == NULL) {
-        return SET_ERROR(ERR_INTERNAL_PTR);
-    }
-#endif
-
-    /* retrieve the 'connect' RPC template, if not done already */
-    if (rpc == NULL) {
-        rpc = ncx_find_object(get_yangcli_mod(), YANGCLI_CONNECT);
-        if (rpc == NULL) {
-            server_cb->state = MGR_IO_ST_IDLE;
-            log_write("\nError finding the 'connect' RPC method");
-            return ERR_NCX_DEF_NOT_FOUND;
-        }
-    }            
-
-    obj = obj_find_child(rpc, NULL, YANG_K_INPUT);
-    if (obj == NULL) {
-        server_cb->state = MGR_IO_ST_IDLE;
-        log_write("\nError finding the connect RPC 'input' node");        
-        return SET_ERROR(ERR_INTERNAL_VAL);
-    }
-
-    res = NO_ERR;
-    tcp = FALSE;
-
-    connect_valset = get_connect_valset();
-
-    /* process any parameters entered on the command line */
-    valset = NULL;
-#if 0
-    if (line != NULL) {
-        while (line[start] && xml_isspace(line[start])) {
-            start++;
-        }
-        if (line[start]) {
-            valset = parse_rpc_cli(server_cb, rpc, &line[start], &res);
-            if (valset == NULL || res != NO_ERR) {
-                if (valset != NULL) {
-                    val_free_value(valset);
-                }
-                log_write("\nError in the parameters for '%s' command (%s)",
-                          obj_get_name(rpc), 
-                          get_error_string(res));
-                server_cb->state = MGR_IO_ST_IDLE;
-                return res;
-            }
-        }
-    }
-#endif
-    if (valset == NULL) {
-        if (startupmode) {
-            /* just clone the connect valset to start with */
-            valset = val_clone(connect_valset);
-            if (valset == NULL) {
-                server_cb->state = MGR_IO_ST_IDLE;
-                log_write("\nError: malloc failed");
-                return ERR_INTERNAL_MEM;
-            }
-        } else {
-            valset = val_new_value();
-            if (valset == NULL) {
-                log_write("\nError: malloc failed");
-                server_cb->state = MGR_IO_ST_IDLE;
-                return ERR_INTERNAL_MEM;
-            } else {
-                val_init_from_template(valset, obj);
-            }
-        }
-    }
-
-    /* make sure the 3 required parms are set */
-    s1 = val_find_child(valset, YANGCLI_MOD, 
-                        YANGCLI_SERVER) ? TRUE : FALSE;
-    s2 = val_find_child(valset, YANGCLI_MOD,
-                        YANGCLI_USER) ? TRUE : FALSE;
-    s3 = val_find_child(valset, YANGCLI_MOD,
-                        YANGCLI_PASSWORD) ? TRUE : FALSE;
-    s4 = val_find_child(valset, YANGCLI_MOD,
-                        YANGCLI_PUBLIC_KEY) ? TRUE : FALSE;
-    s5 = val_find_child(valset, YANGCLI_MOD,
-                        YANGCLI_PRIVATE_KEY) ? TRUE : FALSE;
-
-    /* check the transport parameter */
-    testval = val_find_child(valset, 
-                             YANGCLI_MOD,
-                             YANGCLI_TRANSPORT);
-    if (testval != NULL && 
-        testval->res == NO_ERR && 
-        !xml_strcmp(VAL_ENUM_NAME(testval),
-                    (const xmlChar *)"tcp")) {
-        tcp = TRUE;
-    }
-#if 0    
-    /* complete the connect valset if needed
-     * and transfer it to the server_cb version
-     *
-     * try to get any missing params in valset 
-     */
-    if (interactive_mode()) {
-        if (startupmode && s1 && s2 && ((s3 || (s4 && s5)) || tcp)) {
-            if (LOGDEBUG3) {
-                log_debug3("\nyangcli: CLI direct connect mode");
-            }
-        } else {
-            res = fill_valset(server_cb, rpc, valset, connect_valset, 
-                              TRUE, FALSE);
-            if (res == ERR_NCX_SKIPPED) {
-                res = NO_ERR;
-            }
-        }
-    }
-#endif
-    /* check error or operation canceled */
-    if (res != NO_ERR) {
-        if (res != ERR_NCX_CANCELED) {
-            log_write("\nError: Connect failed (%s)", 
-                      get_error_string(res));
-        }
-        server_cb->state = MGR_IO_ST_IDLE;
-        val_free_value(valset);
-        return res;
-    }
-
-    /* passing off valset memory here */
-    s1 = s2 = s3 = s4 = s5 = FALSE;
-    if (valset != NULL) {
-        /* save the malloced valset */
-        if (server_cb->connect_valset != NULL) {
-            val_free_value(server_cb->connect_valset);
-        }
-        server_cb->connect_valset = valset;
-
-        /* make sure the 3 required parms are set */
-        s1 = val_find_child(server_cb->connect_valset,
-                            YANGCLI_MOD, 
-                            YANGCLI_SERVER) ? TRUE : FALSE;
-        s2 = val_find_child(server_cb->connect_valset, 
-                            YANGCLI_MOD,
-                            YANGCLI_USER) ? TRUE : FALSE;
-        s3 = val_find_child(server_cb->connect_valset, 
-                            YANGCLI_MOD,
-                            YANGCLI_PASSWORD) ? TRUE : FALSE;
-        s4 = val_find_child(server_cb->connect_valset,
-                            YANGCLI_MOD,
-                            YANGCLI_PUBLIC_KEY) ? TRUE : FALSE;
-        s5 = val_find_child(server_cb->connect_valset,
-                            YANGCLI_MOD,
-                            YANGCLI_PRIVATE_KEY) ? TRUE : FALSE;
-    }
-
-    /* check if all params present yet */
-    if (s1 && s2 && ((s3 || (s4 && s5)) || tcp)) {
-
-        res = replace_connect_valset(server_cb->connect_valset);
-        if (res != NO_ERR) {
-            log_warn("\nWarning: connection parameters could not be saved");
-            res = NO_ERR;
-        }
-        create_session(server_cb);
-    } else {
-        res = ERR_NCX_MISSING_PARM;
-        log_write("\nError: Connect failed due to missing parameter(s)");
-        server_cb->state = MGR_IO_ST_IDLE;
-    }
-
-    return res;
-
-}  /* do_connect_ */
-
 status_t yangrpc_init(char* args)
 {
     int ret;
@@ -322,6 +118,7 @@ status_t yangrpc_init(char* args)
      */
     res = ncx_init(NCX_SAVESTR, log_level, TRUE, NULL, p.we_wordc, p.we_wordv);
     if (res != NO_ERR) {
+        yangcli_wordfree(&p);
         return res;
     }
 
@@ -333,6 +130,7 @@ status_t yangrpc_init(char* args)
         }
     }
 #endif
+    yangcli_wordfree(&p);
 
     /* make sure the Yuma directory
      * exists for saving per session data
@@ -365,6 +163,7 @@ status_t yangrpc_init(char* args)
     }
 
     /* Initialize the Netconf Manager Library */
+    mgr_disable_sighandlers();
     res = mgr_init();
     if (res != NO_ERR) {
         return res;
@@ -393,7 +192,6 @@ status_t yangrpc_init(char* args)
     mgr_io_set_stdin_handler(yangcli_stdin_handler);
 #endif
 
-
     return NO_ERR;
 }
 
@@ -447,7 +245,8 @@ status_t
         }
 
         /* skip found modules with errors */          
-        if (!(searchresult->res == ERR_NCX_WRONG_VERSION ||
+        if (searchresult->res != NO_ERR &&
+            !(searchresult->res == ERR_NCX_WRONG_VERSION ||
               searchresult->res == ERR_NCX_MOD_NOT_FOUND)) {
             continue;
         }
@@ -463,14 +262,16 @@ status_t
         }
         /* exit loop if we get here */
 #else
-	printf("<get-schema>:%s\n",searchresult->module);
+	log_info("\n<get-schema>:%s",searchresult->module);
         res = make_get_schema_reqdata(server_cb,
                                       scb,
                                       searchresult->module,
                                       searchresult->revision,
                                       &rpc,
                                       &reqdata);
-        assert(res == NO_ERR);
+        if (res != NO_ERR)
+            return res;
+
         res = yangrpc_exec((yangrpc_cb_ptr_t) server_cb, reqdata, &reply_val);
         res = get_schema_reply_to_temp_filcb(server_cb, (mgr_scb_t *)scb->mgrcb /*mscb*/, searchresult->module, searchresult->revision, reply_val);
         if (res != NO_ERR) {
@@ -517,15 +318,29 @@ status_t
                                       scb,
                                       &rpc,
                                       &reqdata);
-    assert(res == NO_ERR);
+    if (res != NO_ERR)
+        return res;
+
     res = yangrpc_exec((yangrpc_cb_ptr_t) server_cb, reqdata, &reply_val);
-    assert(res == NO_ERR);
+    if (res != NO_ERR) {
+        val_free_value(reqdata);
+        return res;
+    }
+
     res = get_yang_library_modules_state_reply_to_searchresult_entries(server_cb, scb, reply_val);
+    val_free_value(reqdata);
+    val_free_value(reply_val);
     return res;
 
 }  /* yang_library_blocking_get_modules */
 
-status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password, char* public_key, char* private_key, char* extra_args, yangrpc_cb_ptr_t* yangrpc_cb_ptr)
+status_t yangrpc_connect(const char * const server, uint16_t port,
+                         const char * const user,
+                         const char * const password,
+                         const char * const public_key,
+                         const char * const private_key,
+                         const char * const extra_args,
+                         yangrpc_cb_ptr_t* yangrpc_cb_ptr)
 {
     char* server_arg;
     char* port_arg;
@@ -533,6 +348,7 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
     char* password_arg;
     char* public_key_arg;
     char* private_key_arg;
+
     char* mandatory_argv[]={"exec-name-dummy", "--server=?", "--port=?", "--user=?", "--password=?", "--private-key=?", "--public-key=?"};
     int mandatory_argc=sizeof(mandatory_argv)/sizeof(char*);
     char** argv;
@@ -549,6 +365,10 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
     int                   ret;
     yangcli_wordexp_t     p;
     obj_template_t       *obj;
+    int                   i;
+
+    /* deviations processing */
+    ncx_save_deviations_t *savedev;
 
     ncx_clear_temp_modQ();
     ncx_clear_session_modQ();
@@ -559,9 +379,13 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
         connect_valset=NULL;
     }
     connect_valset = val_new_value();
-    assert(connect_valset);
+    if (connect_valset == NULL)
+        return ERR_INTERNAL_MEM;
+
     obj = ncx_find_object(yangcli_mod, YANGCLI_CONNECT);
-    assert(obj!=NULL);
+    if (obj == NULL)
+        return ERR_NCX_DEF_NOT_FOUND;
+
     val_init_from_template(connect_valset, obj);
 
     dlq_createSQue(&savedevQ);
@@ -573,43 +397,55 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
         return ERR_INTERNAL_PTR;
     }
     argv = mandatory_argv;
-
     argc=0;
     argv[argc++]="yangrpc-conn-instance";
 
     server_arg = malloc(strlen("--server=")+strlen(server)+1);
-    assert(server_arg!=NULL);
+    if (server_arg==NULL)
+        return ERR_INTERNAL_MEM;
+
     sprintf(server_arg,"--server=%s",server);
     argv[argc++]=server_arg;
 
     port_arg = malloc(strlen("--ncport=")+strlen("65535")+1);
-    assert(port_arg!=NULL);
+    if (port_arg==NULL)
+        return ERR_INTERNAL_MEM;
+
     sprintf(port_arg,"--ncport=%u", (unsigned int)port);
     argv[argc++]=port_arg;
 
     user_arg = malloc(strlen("--user=")+strlen(user)+1);
-    assert(user_arg!=NULL);
+    if (user_arg==NULL)
+        return ERR_INTERNAL_MEM;
+
     sprintf(user_arg,"--user=%s",user);
     argv[argc++]=user_arg;
 
     /* at least password or public_key and private_key pair has to be specified */
-    assert(password!=NULL || (public_key!=NULL && private_key!=NULL));
+    if (!(password!=NULL || (public_key!=NULL && private_key!=NULL)))
+        return ERR_INTERNAL_MEM;
 
     if(password!=NULL) {
         password_arg = malloc(strlen("--password=")+strlen(password)+1);
-        assert(password_arg!=NULL);
+        if (password_arg==NULL)
+            return ERR_INTERNAL_MEM;
+
         sprintf(password_arg,"--password=%s",password);
         argv[argc++]=password_arg;
     }
 
     if(public_key!=NULL && private_key!=NULL) {
         public_key_arg = malloc(strlen("--public-key=")+strlen(public_key)+1);
-        assert(public_key_arg!=NULL);
+        if (public_key_arg==NULL)
+            return ERR_INTERNAL_MEM;
+
         sprintf(public_key_arg,"--public-key=%s",public_key);
         argv[argc++]=public_key_arg;
 
         private_key_arg = malloc(strlen("--private-key=")+strlen(private_key)+1);
-        assert(private_key_arg!=NULL);
+        if (private_key_arg==NULL)
+            return ERR_INTERNAL_MEM;
+
         sprintf(private_key_arg,"--private-key=%s",private_key);
         argv[argc++]=private_key_arg;
     }
@@ -635,6 +471,11 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
 
     /* Get any command line and conf file parameters */
     res = process_cli_input(server_cb, argc, argv);
+
+    /* Skip argv[0] - it was not allocated with malloc */
+    for(i=1;i<argc;i++) {
+        free(argv[i]);
+    }
     if (res != NO_ERR) {
         log_error("\n process_cli_input failed (%s)", get_error_string(res));
         return res;
@@ -702,6 +543,12 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
         }
     }
 
+    res = process_module_deviations(&savedevQ);
+    if (res != NO_ERR) {
+        log_error("\n%s: Failed to process deviations.", __func__);
+        return res;
+    }
+
     /* discard any deviations loaded from the CLI or conf file */
     ncx_clean_save_deviationsQ(&savedevQ);
     if (res != NO_ERR) {
@@ -773,7 +620,7 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
     if (connect_valset) {
         parm = val_find_child(connect_valset, YANGCLI_MOD, YANGCLI_SERVER);
         if (parm && parm->res == NO_ERR) {
-            res = do_connect_(server_cb, NULL, NULL, 0, TRUE);
+            res = do_connect(server_cb, NULL, NULL, 0, TRUE);
             if (res != NO_ERR) {
                 if (FALSE /*!batchmode*/) {
                     res = NO_ERR;
@@ -792,10 +639,13 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
         mgr_scb_t* mscb;
 
         scb = mgr_ses_get_scb(server_cb->mysid);
-        assert(scb!=NULL);
+        if (scb == NULL)
+            return ERR_INTERNAL_VAL;
 
         res = ses_msg_send_buffs(scb);
-        assert(res==NO_ERR);
+        if (res != NO_ERR)
+            return res;
+
         while(1) {
             res = ses_accept_input(scb);
             if(res!=NO_ERR) {
@@ -813,6 +663,15 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
         report_capabilities(server_cb, scb, TRUE, HELP_MODE_NONE);
         check_module_capabilities(server_cb, scb, autoload_blocking_get_modules, yang_library_blocking_get_module_set);
 
+        if (scb != NULL && server_cb->deviations_applied == FALSE) {
+            ncx_set_session_modQ(&mscb->temp_modQ);
+            ncx_set_cur_modQ(&mscb->temp_modQ);
+            process_module_deviations(&server_cb->autoload_savedevQ);
+            server_cb->deviations_applied = TRUE;
+            ncx_reset_modQ();
+            ncx_clear_session_modQ();
+        }
+
     }
 
     *yangrpc_cb_ptr = (yangrpc_cb_ptr_t)server_cb;
@@ -820,6 +679,7 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
 }
 
 val_value_t* global_reply_val;
+status_t global_reply_status;
 
 /********************************************************************
  * FUNCTION yangcli_reply_handler_
@@ -889,7 +749,10 @@ void
 #else
         //val_dump_value(rpy->reply,0);
         global_reply_val = val_clone(rpy->reply);
-        assert(global_reply_val!=NULL);
+        if (global_reply_val == NULL) {
+            log_error("\nRPC Failed to clone reply");
+            global_reply_status = ERR_INTERNAL_VAL;
+        }
 #endif
     }
 
@@ -902,7 +765,9 @@ void
 }  /* yangcli_reply_handler_ */
 
 #include "yangcli_cmd.h"
-status_t yangrpc_parse_cli(yangrpc_cb_ptr_t yangrpc_cb_ptr, char* original_line, val_value_t** request_val)
+status_t yangrpc_parse_cli(yangrpc_cb_ptr_t yangrpc_cb_ptr,
+                           const char * const original_line,
+                           val_value_t** request_val)
 {
 
 
@@ -996,7 +861,16 @@ status_t yangrpc_parse_cli(yangrpc_cb_ptr_t yangrpc_cb_ptr, char* original_line,
             uint32 timeval;
             res = do_local_conn_command_reqdata(server_cb, rpc, useline, len, &reqdata, &timeval);
             if (res == ERR_NCX_SKIPPED) {
+#ifdef DEBUG
                 assert(0);
+#else
+		log_error("\nError: %s\n", get_error_string(res));
+		if (newline) {
+		    m__free(newline);
+		}
+		return res;
+#endif /* DEBUG */
+
 		/*res = do_local_command(server_cb, rpc, useline, len);*/
             }
         }
@@ -1075,6 +949,7 @@ status_t yangrpc_parse_cli(yangrpc_cb_ptr_t yangrpc_cb_ptr, char* original_line,
         }
     }
     *request_val = reqdata;
+    free(line);
     return res;
 }
 
@@ -1108,28 +983,51 @@ status_t yangrpc_exec(yangrpc_cb_ptr_t yangrpc_cb_ptr, val_value_t* request_val,
 
     /* the request will be stored if this returns NO_ERR */
     global_reply_val=NULL;
+    global_reply_status=NO_ERR;
     res = mgr_rpc_send_request(scb, req, yangcli_reply_handler_);
 
     //mgr_io_run();
     res = ses_msg_send_buffs(scb);
-    assert(res==NO_ERR);
+    if (res != NO_ERR)
+        return res;
+
     while(1) {
     	
         res = ses_accept_input(scb);
         if(res!=NO_ERR) {
-            printf("error: ses_accept_input res=%d\n",res);
-            assert(0);
+            log_error("\nerror: ses_accept_input res=%d",res);
+            return res;
         }
-        if(mgr_ses_process_first_ready() && global_reply_val!=NULL) {
+        if(global_reply_status != NO_ERR ||
+           (mgr_ses_process_first_ready() && global_reply_val!=NULL)) {
             break;
         }
     }
     *reply_val = global_reply_val;
 
-    return NO_ERR;
+    return global_reply_status;
 }
 
 void yangrpc_close(yangrpc_cb_ptr_t yangrpc_cb_ptr)
 {
+    server_cb_t* server_cb;
+    server_cb = (server_cb_t*)yangrpc_cb_ptr;
+
     log_info("Closing session\n");
+
+    if(connect_valset!=NULL) {
+        val_free_value(connect_valset);
+    }
+    connect_valset = val_new_value();
+
+    free_server_cb(server_cb);
+
+    /* Cleanup the Netconf Server Library */
+    mgr_cleanup();
+
+    /* cleanup the module library search results */
+    ncxmod_clean_search_result_queue(&modlibQ);
+
+    /* cleanup the NCX engine and registries */
+    ncx_cleanup();
 }
