@@ -24,8 +24,6 @@
 #include <memory.h>
 #include <ctype.h>
 
-#include <libxml/xmlstring.h>
-#include <libxml/xmlreader.h>
 #include  "procdefs.h"
 #include "c_util.h"
 #include "dlq.h"
