@@ -21,9 +21,9 @@ def main():
 	conn_raw = litenc.litenc()
 	ret = conn_raw.connect(server=server, port=port, user=os.getenv('USER'))
 	if ret != 0:
-		print "[FAILED] Connecting to server=%(server)s:" % {'server':server}
+		print("[FAILED] Connecting to server=%(server)s:" % {'server':server})
 		return(-1)
-	print "[OK] Connecting to server=%(server)s:" % {'server':server}
+	print("[OK] Connecting to server=%(server)s:" % {'server':server})
 	conn=litenc_lxml.litenc_lxml(conn_raw, strip_namespaces=True)
 	ret = conn_raw.send("""
 <hello>
@@ -40,7 +40,7 @@ def main():
 		print("[FAILED] Receiving <hello>")
 		return(-1)
 
-	print "[OK] Receiving <hello> =%(reply_xml)s:" % {'reply_xml':reply_xml}
+	print("[OK] Receiving <hello> =%(reply_xml)s:" % {'reply_xml':reply_xml})
 
 
 	print("Connected ...")
@@ -65,9 +65,9 @@ def main():
 	print("edit-config - create 'foo' ...")
 	result = conn.rpc(edit_rpc%{'interface':"foo"})
 	ok = result.xpath('ok')
-	print result
-	print ok
-	print lxml.etree.tostring(result)
+	print(result)
+	print(ok)
+	print(lxml.etree.tostring(result))
 	assert(len(ok)==1)
 
 	commit_rpc = """
