@@ -3,7 +3,7 @@
 import time
 import sys, os
 import argparse
-from yangcli import yangcli
+from yangcli.yangcli import yangcli
 from lxml import etree
 import yangrpc
 
@@ -65,10 +65,10 @@ def main():
 	result = yangcli(conn, "xget /interfaces")
 	names = result.xpath('./data/interfaces/interface/name')
 	for name in names:
-		print name.text
+		print(name.text)
 	types = result.xpath('./data/interfaces/interface/type')
 	for type in types:
-		print type.text
+		print(type.text)
 
 	assert(len(types)==1)
 	assert(types[0].text=='ianaift:ethernetCsmacd')
@@ -82,10 +82,10 @@ def main():
 	result = yangcli(conn, "xget /interfaces")
 	names = result.xpath('./data/interfaces/interface/name')
 	for name in names:
-		print name.text
+		print(name.text)
 	types = result.xpath('./data/interfaces/interface/type')
 	for type in types:
-		print type.text
+		print(type.text)
 
 	assert(len(types)==1)
 	assert(types[0].text=='ianaift:other')
