@@ -48,9 +48,9 @@ def main():
 	conn_raw = litenc.litenc()
 	ret = conn_raw.connect(server=server, port=port, user=user, password=password)
 	if ret != 0:
-		print "[FAILED] Connecting to server=%(server)s:" % {'server':server}
+		print("[FAILED] Connecting to server=%(server)s:" % {'server':server})
 		return(-1)
-	print "[OK] Connecting to server=%(server)s:" % {'server':server}
+	print("[OK] Connecting to server=%(server)s:" % {'server':server})
 	conn=litenc_lxml.litenc_lxml(conn_raw, strip_namespaces=True)
 	ret = conn_raw.send("""
 <hello xmlns="urn:ietf:params:xml:ns:netconf:base:1.0">
@@ -67,9 +67,9 @@ def main():
 	result=conn.receive()
 
 	print("#1 - Print the <hello>")
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 
-        print("#2 - Print the operational state.")
+	print("#2 - Print the operational state.")
 
 	get_rpc = """
 <get xmlns="urn:ietf:params:xml:ns:netconf:base:1.0">
@@ -78,7 +78,7 @@ def main():
 	print("get / ...")
 	result = conn.rpc(get_rpc)
 
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 
 	delete_config_rpc = """
   <edit-config xmlns="urn:ietf:params:xml:ns:netconf:base:1.0">
@@ -107,7 +107,7 @@ def main():
 """
 	print("commit ...")
 	result = conn.rpc(commit_rpc)
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 	ok = result.xpath('ok')
 	assert(len(ok)==1)
 
@@ -163,7 +163,7 @@ def main():
 
 	print("edit-config ...")
 	result = conn.rpc(edit_config_rpc)
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 	ok = result.xpath('ok')
 	assert(len(ok)==1)
 
@@ -172,7 +172,7 @@ def main():
 """
 	print("commit ...")
 	result = conn.rpc(commit_rpc)
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 	ok = result.xpath('ok')
 	assert(len(ok)==1)
 
