@@ -1,4 +1,4 @@
-from yangcli import yangcli
+from yangcli.yangcli import yangcli
 from lxml import etree
 import yangrpc
 import sys
@@ -6,8 +6,8 @@ import os
 
 conn = yangrpc.connect("127.0.0.1", 830, os.getenv('USER'), None, os.getenv('HOME')+"/.ssh/id_rsa.pub", os.getenv('HOME')+"/.ssh/id_rsa",)
 if(conn==None):
-    print("Error: yangrpc failed to connect!")
-    sys.exit(1)
+	print("Error: yangrpc failed to connect!")
+	sys.exit(1)
 
 
 result=yangcli(conn, "commit")
