@@ -2,7 +2,8 @@
 
 apt-get update
 apt-get -y upgrade
-apt-get -y install git devscripts
+apt-get -y install git devscripts \
+	equivs
 
 #getting/building/installing
 cd ~
@@ -30,7 +31,7 @@ cd yuma123_${ver}
 debuild -us -uc
 dpkg -i ../*.deb
 
-#build and install python-yuma (used in the testsuite)
+#build and install python3-yuma (used in the testsuite)
 cd ~
 apt-get -y install rsync
 rsync -rav yuma123_${ver}/netconf/python/ yuma123-python_${ver}
@@ -42,13 +43,13 @@ rm -rf yuma123-python_${ver}
 tar -xzvf yuma123-python_${ver}.orig.tar.gz
 cd yuma123-python_${ver}
 debuild -us -uc
-apt-get -y install python-paramiko python-lxml
-dpkg -i ../python-yuma*.deb
+apt-get -y install python3-paramiko python3-lxml
+dpkg -i ../python3-yuma*.deb
 
 #testing
-ssh-keygen -t rsa -N "" -f ~/.ssh/id_rsa
+apt-get -y install openssh-client openssh-server
+ssh-keygen -t rsa -b 4096 -m PEM -f ~/.ssh/id_rsa -N ""
 cat ~/.ssh/id_rsa.pub >> ~/.ssh/authorized_keys
-ssh-keyscan -t rsa -H localhost >> ~/.ssh/known_hosts
 echo "PermitRootLogin yes" >> /etc/ssh/sshd_config
 echo "Port 22" >> /etc/ssh/sshd_config
 echo "Port 830" >> /etc/ssh/sshd_config
@@ -59,10 +60,14 @@ echo "Port 4830" >> /etc/ssh/sshd_config
 echo "Port 5830" >> /etc/ssh/sshd_config
 echo "Port 6830" >> /etc/ssh/sshd_config
 echo 'Subsystem netconf "/usr/sbin/netconf-subsystem --ncxserver-sockname=830@/tmp/ncxserver.sock --ncxserver-sockname=1830@/tmp/ncxserver.1830.sock --ncxserver-sockname=2830@/tmp/ncxserver.2830.sock --ncxserver-sockname=3830@/tmp/ncxserver.3830.sock --ncxserver-sockname=4830@/tmp/ncxserver.4830.sock --ncxserver-sockname=5830@/tmp/ncxserver.5830.sock --ncxserver-sockname=6830@/tmp/ncxserver.6830.sock"' >> /etc/ssh/sshd_config
-/etc/init.d/ssh restart
+
+/etc/init.d/ssh restart || true
+ssh-keyscan -t rsa -H localhost >> ~/.ssh/known_hosts
 
 cd ~/yuma123_${ver}/netconf/test/netconfd
-apt-get -y install python-ncclient valgrind
+apt-get -y install python3-ncclient valgrind
+apt-get -y install python-is-python3
+apt-get -y install psmisc # contains killall
 
 multiarch=$(dpkg-architecture -q DEB_BUILD_MULTIARCH)
 prefix="/usr"
